@@ -65,7 +65,7 @@ glimpse.tbl <- function(x, width = NULL, ...) {
 
   # for some reason the offset was -2 in tibble but is now -1
   # so that the desired width is obtained
-  data_width <- width - crayon::col_nchar(var_names) - 1
+  data_width <- width - get_extent(var_names) - 1
   formatted <- map_chr(df, format_glimpse_1)
   truncated <- str_trunc(formatted, data_width)
 
@@ -100,7 +100,7 @@ glimpse.default <- function(x, width = NULL, max.level = 3, ...) {
 #' Empty vectors are shown as `<>`.
 #'
 #' @return A character vector of the same length as `x`.
-#' @inheritParams ellipsis::dots_used
+#' @inheritParams rlang::args_dots_used
 #' @param x A vector.
 #' @export
 #' @examples
@@ -127,8 +127,12 @@ format_glimpse <- function(x, ...) {
 }
 
 # A variant with collapse and without checks, for format_glimpse.list()
-format_glimpse_1 <- function(x, ...) {
-  collapse(format_glimpse_(x, ...))
+format_glimpse_1 <- function(x, ..., .inner = NULL) {
+  if (!is_null(.inner) && .inner) {
+    collapse(format_glimpse_(x, ..., .inner = .inner))
+  } else {
+    paste0(format_glimpse_(x, ...), collapse = crayon_grey_0.6(", "))
+  }
 }
 
 format_glimpse_ <- function(x, ...) {
@@ -140,11 +144,12 @@ format_glimpse_ <- function(x, ...) {
 format_glimpse.default <- function(x, ...) {
   dims <- dim(x)
 
-  if (!is.null(dims)) {
+  if (is.null(dims)) {
+    out <- format(x, trim = TRUE, justify = "none")
+    style_na_if(out, if (is.atomic(x)) is.na(x) else FALSE)
+  } else {
     dims_out <- paste0(dims, collapse = " x ")
     paste0("<", class(x)[[1]], "[", dims_out, "]>")
-  } else {
-    format(x, trim = TRUE, justify = "none")
   }
 }
 
@@ -155,7 +160,6 @@ format_glimpse.list <- function(x, ..., .inner = FALSE) {
   }
 
   out <- map_chr(x, format_glimpse_1, .inner = TRUE)
-
   # Surround vectors by <>
   # Only surround inner lists by []
   list <- map_lgl(x, is.list)
@@ -169,14 +173,16 @@ format_glimpse.list <- function(x, ..., .inner = FALSE) {
 
 #' @export
 format_glimpse.character <- function(x, ...) {
-  encodeString(x, quote = '"')
+  out <- encodeString(as.character(x), quote = '"')
+  style_na_if(out, is.na(x))
 }
 
 #' @export
 format_glimpse.factor <- function(x, ...) {
   if (any(grepl(",", levels(x), fixed = TRUE))) {
-    encodeString(as.character(x), quote = '"')
+    out <- encodeString(as.character(x), quote = '"')
   } else {
-    format(x, trim = TRUE, justify = "none")
+    out <- format(x, trim = TRUE, justify = "none")
   }
+  style_na_if(out, is.na(x))
 }
